@@ -14,24 +14,24 @@
 #' @export
 relative_to <- function(dir, file) {
   # ensure directory ends with a /
-  if (!identical(substr(dir, nchar(dir), nchar(dir)), "/")) {
-    dir <- paste0(dir, "/")
-  }
+  dir <- sub('/+$', '/', paste0(dir, '/'))
 
   # if the file is prefixed with the directory, return a relative path
   if (identical(substr(file, 1, nchar(dir)), dir))
     file <- substr(file, nchar(dir) + 1, nchar(file))
 
   # simplify ./
-  if (identical(substr(file, 1, 2), "./"))
-    file <- substr(file, 3, nchar(file))
-
-  file
+  sub('^[.]/', '', file)
 }
 
 # A variant of relative_to that normalizes its inputs.
 normalized_relative_to <- function(dir, file) {
   relative_to(
-    normalize_path(dir, mustWork = FALSE),
-    normalize_path(file, mustWork = FALSE))
+    normalize_path(dir, must_work = FALSE),
+    normalize_path(file, must_work = FALSE))
+}
+
+# If a path is a relative path, it should be the same as ./path
+is_relative <- function(path) {
+  same_path(path, file.path('.', path), must_work = FALSE)
 }
